@@ -106,7 +106,7 @@
 
 ;;;; Functions
 
-(defun consult-denote-file-prompt (&optional files-matching-regexp prompt-text no-require-match)
+(defun consult-denote-file-prompt (&optional files-matching-regexp prompt-text no-require-match has-identifier)
   "A Consult-powered equivalent of `denote-file-prompt'.
 
 With optional FILES-MATCHING-REGEXP, filter the candidates per
@@ -117,21 +117,24 @@ select a file.
 
 With optional NO-REQUIRE-MATCH, accept the given input as-is.
 
+With optional HAS-IDENTIFIER, only show candidates that have an
+identifier.
+
 Return the absolute path to the matching file."
   (let* ((relative-files (mapcar
                           #'denote-get-file-name-relative-to-denote-directory
                           (denote-directory-files
                            (or denote-file-prompt-use-files-matching-regexp files-matching-regexp)
-                           :omit-current)))
-         (prompt (format "%s in %s: " (or prompt-text "Select FILE") (denote-directory)))
+                           :omit-current nil nil has-identifier)))
          (default-directory (denote-directory)) ; needed for the preview
+         (prompt (format "%s in %s: " (or prompt-text "Select FILE") default-directory))
          (input (consult--read
                  (denote--completion-table 'file relative-files)
                  :state (consult--file-preview)
                  :require-match (unless no-require-match :require-match)
                  :history 'denote-file-history
                  :prompt prompt))
-         (absolute-file (concat (denote-directory) input)))
+         (absolute-file (expand-file-name input (denote-directory))))
     ;; NOTE: This block is executed when no-require-match is t. It is useful
     ;; for commands such as `denote-open-or-create` or similar.
     (unless (file-exists-p absolute-file)
@@ -142,6 +145,25 @@ Return the absolute path to the matching file."
     ;; appropriately.
     absolute-file))
 
+(defun consult-denote-sequence-file-prompt (&optional prompt-text files-with-sequences)
+  "A Consult-powered equivalent of `denote-sequence-file-prompt'.
+
+With optional PROMPT-TEXT use it instead of a generic prompt.
+
+With optional FILES-WITH-SEQUENCES as a list of strings, use them as
+completion candidates.  Else use `denote-sequence-get-all-files'."
+  (if-let* ((relative-files (mapcar #'denote-get-file-name-relative-to-denote-directory
+                                    (or files-with-sequences (denote-sequence-get-all-files))))
+            (prompt (format-prompt (or prompt-text "Select FILE with sequence") nil))
+            (input (consult--read
+                    (denote--completion-table 'file relative-files)
+                    :state (consult--file-preview)
+                    :require-match nil
+                    :history 'denote-sequence-file-history
+                    :prompt prompt)))
+      (expand-file-name input (denote-directory))
+    (error "There are no sequence notes in the `denote-directory'")))
+
 (defun consult-denote-select-linked-file-prompt (files)
   "Prompt for linked file among FILES."
   (let ((file-names (mapcar #'denote-get-file-name-relative-to-denote-directory
@@ -188,14 +210,23 @@ FILE has the same meaning as in `denote-org-extras-outline-prompt'."
   "Call `consult-denote-grep-command' in the variable `denote-directory'."
   (declare (interactive-only t))
   (interactive)
-  (funcall-interactively consult-denote-grep-command (denote-directory)))
+  (if (denote-has-single-denote-directory-p)
+      (funcall-interactively consult-denote-grep-command (denote-directory))
+    (let* ((directories (mapconcat #'identity (denote-directories) " "))
+           (consult-grep-args `("grep" (consult--grep-exclude-args) "--null --line-buffered --color=never --ignore-case --with-filename --line-number -I -r" ,directories))
+           (consult-ripgrep-args (format "rg --null --line-buffered --color=never --max-columns=1000 --path-separator --smart-case --no-heading --with-filename --line-number --search-zip %s" directories)))
+      (funcall-interactively consult-denote-grep-command))))
 
 ;;;###autoload
 (defun consult-denote-find ()
   "Call `consult-denote-find-command' in the variable `denote-directory'."
   (declare (interactive-only t))
   (interactive)
-  (funcall-interactively consult-denote-find-command (denote-directory)))
+  (if (denote-has-single-denote-directory-p)
+      (funcall-interactively consult-denote-find-command (denote-directory))
+    (let* ((directories (mapconcat #'identity (denote-directories) " "))
+           (consult-find-args  (format "find %s -not ( -path */.[A-Za-z]* -prune )" directories)))
+      (funcall-interactively consult-denote-find-command))))
 
 (consult-customize consult-denote-find :state (consult--file-preview))
 
@@ -278,14 +309,16 @@ FILE has the same meaning as in `denote-org-extras-outline-prompt'."
         (advice-add #'denote-select-linked-file-prompt :override #'consult-denote-select-linked-file-prompt)
         ;; See FIXME where this function is defined.
         (advice-add #'denote-org-extras-outline-prompt :override #'consult-denote-outline-prompt)
-        (advice-add #'denote-silo-extras-directory-prompt :override #'consult-denote-silo-directory-prompt))
+        (advice-add #'denote-silo-extras-directory-prompt :override #'consult-denote-silo-directory-prompt)
+        (advice-add #'denote-sequence-file-prompt :override #'consult-denote-sequence-file-prompt))
     (dolist (source consult-denote-buffer-sources)
       (setq consult-buffer-sources (delq source consult-buffer-sources)))
     (advice-remove #'denote-file-prompt #'consult-denote-file-prompt)
     (advice-remove #'denote-select-linked-file-prompt #'consult-denote-select-linked-file-prompt)
     (advice-remove #'denote-select-linked-file-prompt #'consult-denote-select-linked-file-prompt)
     (advice-remove #'denote-org-extras-outline-prompt #'consult-denote-outline-prompt)
-    (advice-remove #'denote-silo-extras-directory-prompt #'consult-denote-silo-directory-prompt)))
+    (advice-remove #'denote-silo-extras-directory-prompt #'consult-denote-silo-directory-prompt)
+    (advice-remove #'denote-sequence-file-prompt #'consult-denote-sequence-file-prompt)))
 
 (provide 'consult-denote)
 ;;; consult-denote.el ends here
